@@ -13,8 +13,8 @@
 #include <kcmutils_version.h>
 
 #include "ui_kcm.h"
-#include "interfaces/dbusinterfaces.h"
-#include "interfaces/devicesmodel.h"
+#include "dbusinterfaces.h"
+#include "devicesmodel.h"
 #include "devicessortproxymodel.h"
 #include "kdeconnect-version.h"
 
@@ -221,6 +221,7 @@ void KdeConnectKcm::resetDeviceView()
     delete kcmUi->pluginSelector;
     kcmUi->pluginSelector = new KPluginSelector(this);
     kcmUi->deviceInfo_layout->addWidget(kcmUi->pluginSelector);
+    kcmUi->verificationKey->setText(i18n("Key: %1", QString::fromUtf8(currentDevice->verificationKey())));
 
     kcmUi->pluginSelector->setConfigurationArguments(QStringList(currentDevice->id()));
 
